@@ -1,6 +1,6 @@
 package Courriel;
 {
-  $Courriel::VERSION = '0.26';
+  $Courriel::VERSION = '0.28';
 }
 
 use 5.10.0;
@@ -38,6 +38,7 @@ has top_level_part => (
             content_type
             headers
             is_multipart
+            stream_to
             )
     ]
 );
@@ -419,7 +420,7 @@ sub _parse_headers {
     # Some broken emails may split the From line in an arbitrary spot
     ${$text} =~ s/^[^:]+$Courriel::Helpers::LINE_SEP_RE//g;
 
-    if ( ${$text} =~ /(.+?)($Courriel::Helpers::LINE_SEP_RE)\2/s ) {
+    if ( ${$text} =~ /^(.+?)($Courriel::Helpers::LINE_SEP_RE)\g{2}/s ) {
         $header_text = $1 . $2;
         $sep_idx     = ( length $header_text ) + ( length $2 );
         $line_sep    = $2;
@@ -473,14 +474,12 @@ sub _parse_multipart {
     my $headers = shift;
     my $ct      = shift;
 
-    my $boundary_attr = $ct->attribute('boundary');
+    my $boundary = $ct->attribute_value('boundary');
 
     die q{The message's mime type claims this is a multipart message (}
         . $ct->mime_type()
         . q{) but it does not specify a boundary.}
-        unless $boundary_attr && length $boundary_attr->value();
-
-    my $boundary = $boundary_attr->value();
+        unless defined $boundary && length $boundary;
 
     my ( $preamble, $all_parts, $epilogue ) = ${$text} =~ /
                 (.*?)                   # preamble
@@ -534,7 +533,7 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.26
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -696,6 +695,16 @@ Returns the L<Courriel::Header::ContentType> object associated with the email.
 
 Returns the L<Courriel::Headers> object for this email.
 
+=head2 $email->stream_to( output => $output )
+
+This method will send the stringified email to the specified output. The
+output can be a subroutine reference, a filehandle, or an object with a
+C<print()> method. The output may be sent as a single string, as a list of
+strings, or via multiple calls to the output.
+
+For large emails, streaming can be much more memory efficient than generating
+a single string in memory.
+
 =head2 $part->as_string()
 
 Returns the email as a string, along with its headers. Lines will be
@@ -766,7 +775,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2012 by Dave Rolsky.
 
 This is free software, licensed under:
 
