@@ -1,6 +1,6 @@
 package Courriel::Header::ContentType;
 {
-  $Courriel::Header::ContentType::VERSION = '0.27';
+  $Courriel::Header::ContentType::VERSION = '0.28';
 }
 
 use strict;
@@ -95,7 +95,7 @@ Courriel::Header::ContentType - The content type for an email part
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -187,6 +187,10 @@ Returns a hash (not a reference) of the attributes passed to the constructor.
 
 Attributes are L<Courriel::HeaderAttribute> objects.
 
+The keys of the hash are all lower case, though the original casing is
+preserved in the C<name()> returned by the L<Courriel::HeaderAttribute>
+object.
+
 =head2 $ct->is_binary()
 
 Returns true unless the attachment looks like text data. Currently, this means
@@ -194,13 +198,17 @@ that is has a charset defined and the charset is not "binary".
 
 =head2 $ct->attribute($key)
 
-Given a key, returns the named L<Courriel::HeaderAttribute>
-object. Obviously, this value can be C<undef> if the attribute doesn't exist.
+Given a key, returns the named L<Courriel::HeaderAttribute> object. Obviously,
+this value can be C<undef> if the attribute doesn't exist. Name lookup is
+case-insensitive.
 
 =head2 $ct->attribute_value($key)
 
 Given a key, returns the named attribute's value as a string. Obviously, this
-value can be C<undef> if the attribute doesn't exist.
+value can be C<undef> if the attribute doesn't exist. Name lookup is
+case-insensitive.
+
+The attribute is a L<Courriel::HeaderAttribute> object.
 
 =head2 $ct->as_header_value()
 
@@ -222,7 +230,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2012 by Dave Rolsky.
 
 This is free software, licensed under:
 
