@@ -1,6 +1,6 @@
 package Courriel::HeaderAttribute;
 {
-  $Courriel::HeaderAttribute::VERSION = '0.26';
+  $Courriel::HeaderAttribute::VERSION = '0.28';
 }
 
 use strict;
@@ -15,6 +15,8 @@ use Encode qw( encode );
 use Moose;
 use MooseX::StrictConstructor;
 
+with 'Courriel::Role::Streams';
+
 has name => (
     is       => 'ro',
     isa      => NonEmptyStr,
@@ -51,6 +53,13 @@ override BUILDARGS => sub {
     return $p;
 };
 
+sub _stream_to {
+    my $self   = shift;
+    my $output = shift;
+
+    $output->( $self->_as_string() );
+}
+
 {
     my $non_attribute_char = qr{
                                    $Courriel::Helpers::TSPECIALS
@@ -62,7 +71,7 @@ override BUILDARGS => sub {
                                    [\x00-\x1f\x7f]   # ctrl chars
                            }x;
 
-    sub as_header_string {
+    sub _as_string {
         my $self = shift;
 
         my $value = $self->value();
@@ -160,6 +169,8 @@ sub _encoded_parameter {
     return $param;
 }
 
+__PACKAGE__->meta()->make_immutable();
+
 1;
 
 # ABSTRACT: A single attribute belonging to a header
@@ -174,7 +185,7 @@ Courriel::HeaderAttribute - A single attribute belonging to a header
 
 =head1 VERSION
 
-version 0.26
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -232,7 +243,7 @@ The attribute's charset.
 
 The attribute's language.
 
-=head2 $attribute->as_header_string()
+=head2 $attribute->as_string()
 
 This returns the attribute in a form suitable for putting in an email. This
 may involve escaping, quoting, splitting up, and otherwise messing with the
@@ -241,13 +252,24 @@ value.
 If the value needs to be split across continuations, each name/value pair is
 returned separate by a space, but not folded across multiple lines.
 
+=head2 $attribute->stream_to( output => $output )
+
+This method will send the stringified attribute to the specified output. The
+output can be a subroutine reference, a filehandle, or an object with a
+C<print()> method. The output may be sent as a single string, as a list of
+strings, or via multiple calls to the output.
+
+=head1 ROLES
+
+This class does the C<Courriel::Role::Streams> role.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2012 by Dave Rolsky.
 
 This is free software, licensed under:
 
